@@ -43,8 +43,12 @@ class PayloadEndpoint(object):
 
     PERMITTER = None
 
-    def __init__(self, filt: Dict, callable_,
-                 acceptOnlyFromVortex: Optional[Union[str,tuple]] = None) -> None:
+    def __init__(
+        self,
+        filt: Dict,
+        callable_,
+        acceptOnlyFromVortex: Optional[Union[str, tuple]] = None,
+    ) -> None:
         """
         :param filt: The filter to match against payloads
         :param callable_: This will be called and passed the payload if it matches
@@ -53,22 +57,25 @@ class PayloadEndpoint(object):
         """
         self._acceptOnlyFromVortex = acceptOnlyFromVortex
         if isinstance(self._acceptOnlyFromVortex, str):
-            self._acceptOnlyFromVortex = (self._acceptOnlyFromVortex, )
+            self._acceptOnlyFromVortex = (self._acceptOnlyFromVortex,)
 
         if not "key" in filt:
-            e = Exception("There is no 'key' in the payload filt"
-                          ", There must be one for routing")
+            e = Exception(
+                "There is no 'key' in the payload filt"
+                ", There must be one for routing"
+            )
             logger.exception(e)
             raise e
 
         self._wref: Callable[[], Optional[Callable]] = None
         if isinstance(callable_, types.FunctionType):
             w = None
-            if hasattr(callable_, '_endpointWeakClass'):
+            if hasattr(callable_, "_endpointWeakClass"):
                 w = callable_._endpointWeakClass
 
             else:
-                class W():
+
+                class W:
                     def __init__(self, callable_):
                         self._callable = callable_
                         self._callable._endpointWeakClass = self
@@ -84,11 +91,11 @@ class PayloadEndpoint(object):
             weakObject = weakref.ref(callable_.__self__)
             weakMethod = weakref.ref(callable_.__func__)
 
-            if callable_.__func__.__name__ == 'func':
+            if callable_.__func__.__name__ == "func":
                 logger.warning(
                     "The registered callback is 'func' this is likely"
                     " a method wrapped in @deferToThreadWrapWithLogger, %s",
-                    filt
+                    filt,
                 )
 
             def getCallable():
@@ -110,7 +117,10 @@ class PayloadEndpoint(object):
     def check(self, payloadEnvelope: PayloadEnvelope, vortexName: str) -> bool:
 
         # Filter for the backend vortexes.
-        if self._acceptOnlyFromVortex and vortexName not in self._acceptOnlyFromVortex:
+        if (
+            self._acceptOnlyFromVortex
+            and vortexName not in self._acceptOnlyFromVortex
+        ):
             return False
 
         def removeUnhashable(filt):
@@ -124,10 +134,13 @@ class PayloadEndpoint(object):
                 if isinstance(value, dict):
                     continue
 
-                if (inspect.isclass(value)
-                        and (issubclass(value, dict) or issubclass(value, list))):
-                    raise Exception("Class type passed instead of an instance"
-                                    " key:%s, value:%s" % (key, value))
+                if inspect.isclass(value) and (
+                    issubclass(value, dict) or issubclass(value, list)
+                ):
+                    raise Exception(
+                        "Class type passed instead of an instance"
+                        " key:%s, value:%s" % (key, value)
+                    )
 
                 items.add((key, value))
             return items
@@ -137,24 +150,33 @@ class PayloadEndpoint(object):
 
         return set(ourFilt).issubset(theirFilt)
 
-    def process(self, payloadEnvelope: PayloadEnvelope,
-                vortexUuid: str, vortexName: str, httpSession,
-                sendResponse: SendVortexMsgResponseCallable):
+    def process(
+        self,
+        payloadEnvelope: PayloadEnvelope,
+        vortexUuid: str,
+        vortexName: str,
+        httpSession,
+        sendResponse: SendVortexMsgResponseCallable,
+    ):
 
         if not self.check(payloadEnvelope, vortexName):
             return
 
-        if self.PERMITTER and not self.PERMITTER.check(payloadEnvelope, httpSession):
+        if self.PERMITTER and not self.PERMITTER.check(
+            payloadEnvelope, httpSession
+        ):
             logger.debug("Permission failed for %s", payloadEnvelope.filt)
             return
 
         callable_ = self._wref()
         if callable_:
-            return callable_(payloadEnvelope=payloadEnvelope,
-                             vortexUuid=vortexUuid,
-                             vortexName=vortexName,
-                             httpSession=httpSession,
-                             sendResponse=sendResponse)
+            return callable_(
+                payloadEnvelope=payloadEnvelope,
+                vortexUuid=vortexUuid,
+                vortexName=vortexName,
+                httpSession=httpSession,
+                sendResponse=sendResponse,
+            )
         else:
             PayloadIO().remove(self)
 
@@ -167,7 +189,8 @@ class PayloadEndpoint(object):
         if callable_:
             try:
                 callbackStr = "%s.%s" % (
-                    callable_.__self__.__class__.__name__, callable_.__name__
+                    callable_.__self__.__class__.__name__,
+                    callable_.__name__,
                 )
             except Exception as e:
                 callbackStr = str(e)
